@@ -1,8 +1,8 @@
-package MooseX::Getopt; # git description: v0.68-24-g0ddcb66
+package MooseX::Getopt; # git description: v0.69-6-g6f5d9e0
 # ABSTRACT: A Moose role for processing command line options
 # KEYWORDS: moose extension command line options attributes executable flags switches arguments
 
-our $VERSION = '0.69';
+our $VERSION = '0.70';
 
 use Moose::Role 0.56;
 use namespace::autoclean;
@@ -23,7 +23,7 @@ MooseX::Getopt - A Moose role for processing command line options
 
 =head1 VERSION
 
-version 0.69
+version 0.70
 
 =head1 SYNOPSIS
 
@@ -317,7 +317,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Tomas Doran Stevan Little Yuval Kogman Florian Ragwitz Brandon L Black Shlomi Fish Olaf Alders Hans Dieter Pearcey Nelo Onyiah Ryan D Johnson Ricardo SIGNES Ævar Arnfjörð Bjarmason Damien Krotkine Hinrik Örn Sigurðsson Todd Hepler Devin Austin Jose Luis Martinez Chris Prather Justin Hunter Stuart A Johnston Dagfinn Ilmari Mannsåker Gordon Irving Jonathan Swartz John Goulah Jesse Luehrs
+=for stopwords Karen Etheridge Tomas Doran Stevan Little Yuval Kogman Florian Ragwitz Brandon L Black Shlomi Fish Hans Dieter Pearcey Olaf Alders Nelo Onyiah Ryan D Johnson Ricardo SIGNES Damien Krotkine Dave Rolsky Hinrik Örn Sigurðsson Ævar Arnfjörð Bjarmason Chris Prather Devin Austin Jose Luis Martinez Todd Hepler Dagfinn Ilmari Mannsåker Gordon Irving Gregory Oschwald Jesse Luehrs John Goulah Jonathan Swartz Justin Hunter Stuart A Johnston
 
 =over 4
 
@@ -351,11 +351,11 @@ Shlomi Fish <shlomif@cpan.org>
 
 =item *
 
-Olaf Alders <olaf@wundersolutions.com>
+Hans Dieter Pearcey <hdp@weftsoar.net>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
+Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
@@ -371,11 +371,11 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =item *
 
-Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+Damien Krotkine <dkrotkine@weborama.com>
 
 =item *
 
-Damien Krotkine <dkrotkine@weborama.com>
+Dave Rolsky <autarch@urth.org>
 
 =item *
 
@@ -383,7 +383,11 @@ Hinrik Örn Sigurðsson <hinrik.sig@gmail.com>
 
 =item *
 
-Todd Hepler <thepler@employees.org>
+Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+
+=item *
+
+Chris Prather <chris@prather.org>
 
 =item *
 
@@ -395,19 +399,7 @@ Jose Luis Martinez <jlmartinez@capside.com>
 
 =item *
 
-Chris Prather <chris@prather.org>
-
-=item *
-
-Shlomi Fish <shlomif@shlomifish.org>
-
-=item *
-
-Justin Hunter <justin.d.hunter@gmail.com>
-
-=item *
-
-Stuart A Johnston <saj_git@thecommune.net>
+Todd Hepler <thepler@employees.org>
 
 =item *
 
@@ -419,7 +411,11 @@ Gordon Irving <goraxe@goraxe.me.uk>
 
 =item *
 
-Jonathan Swartz <swartz@pobox.com>
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
 
 =item *
 
@@ -427,7 +423,19 @@ John Goulah <jgoulah@cpan.org>
 
 =item *
 
-Jesse Luehrs <doy@tozt.net>
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Justin Hunter <justin.d.hunter@gmail.com>
+
+=item *
+
+Shlomi Fish <shlomif@shlomifish.org>
+
+=item *
+
+Stuart A Johnston <saj_git@thecommune.net>
 
 =back
 
